gedidb.H5FileDownloader
=======================

.. currentmodule:: gedidb

.. autoclass:: H5FileDownloader

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~H5FileDownloader.__init__
      ~H5FileDownloader.download
   
   

   
   
   